@@ -1,6 +1,6 @@
 context("predict function")
 
-expect_error(predict(knn_forecasting(ts(1:30), h = 3), h = 4))
+expect_error(predict(knn_forecasting(ts(1:30), msas = "MIMO", h = 3), h = 4))
 
 test_that("MIMO strategy predicts fine", {
   expect_equal(knn_forecasting(ts(1:30), h = 3)$prediction,
